summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorStephan Bergmann <sbergman@redhat.com>2016-03-09 18:21:35 +0100
committerStephan Bergmann <sbergman@redhat.com>2016-03-10 18:32:10 +0100
commit6d711b55d8440d3615923fd983d56d886266f8ea (patch)
tree45250ffedb1ebe9c9ab949b086c41088a3b99b9a /include
parent19a5374b063551e448aa4ece115d6f711fc0772b (diff)
Avoid reserved identifier
Change-Id: I59b2e4859fab89fb7508b8c929d4d586495c6022
Diffstat (limited to 'include')
-rw-r--r--include/svtools/parhtml.hxx2
-rw-r--r--include/svtools/parrtf.hxx2
-rw-r--r--include/svtools/svparser.hxx4
3 files changed, 4 insertions, 4 deletions
diff --git a/include/svtools/parhtml.hxx b/include/svtools/parhtml.hxx
index 5a2c19605afa..4ebc95730d01 100644
--- a/include/svtools/parhtml.hxx
+++ b/include/svtools/parhtml.hxx
@@ -154,7 +154,7 @@ protected:
int _GetNextRawToken();
// scan next token
- virtual int _GetNextToken() override;
+ virtual int GetNextToken_() override;
virtual ~HTMLParser();
diff --git a/include/svtools/parrtf.hxx b/include/svtools/parrtf.hxx
index f98dc7bfb8c2..1c45ddc49d5b 100644
--- a/include/svtools/parrtf.hxx
+++ b/include/svtools/parrtf.hxx
@@ -51,7 +51,7 @@ protected:
void SkipGroup();
// scanne das naechste Token,
- virtual int _GetNextToken() override;
+ virtual int GetNextToken_() override;
void ReadUnknownData();
virtual void ReadBitmapData();
diff --git a/include/svtools/svparser.hxx b/include/svtools/svparser.hxx
index 527c192fc35f..75d07b36cab9 100644
--- a/include/svtools/svparser.hxx
+++ b/include/svtools/svparser.hxx
@@ -97,10 +97,10 @@ protected:
TokenStackType* GetStackPtr( short nCnt );
// scan the next token:
// work off Token stack and call _GetNextToken() if necessary.
// That one is responsible for the recognition of new Tokens.
int GetNextToken();
- virtual int _GetNextToken() = 0;
+ virtual int GetNextToken_() = 0;
// is called for each Token that is recognized in CallParser
virtual void NextToken( int nToken );
@@ -97,10 +97,10 @@ protected:
TokenStackType* GetStackPtr( short nCnt );
// scan the next token:
- // work off Token stack and call _GetNextToken() if necessary.
+ // work off Token stack and call GetNextToken_() if necessary.
// That one is responsible for the recognition of new Tokens.
int GetNextToken();